@@ -1,14 +1,14 @@
 `points.cca` <-
-    function (x, display = "sites", choices = c(1, 2), scaling = 2, 
-              arrow.mul, head.arrow = 0.05, select, const, ...) 
+    function (x, display = "sites", choices = c(1, 2), scaling = 2,
+              arrow.mul, head.arrow = 0.05, select, const, ...)
 {
     formals(arrows) <- c(formals(arrows), alist(... = ))
-    if (length(display) > 1) 
+    if (length(display) > 1)
         stop("Only one 'display' item can be added in one command.")
     pts <- scores(x, choices = choices, display = display, scaling = scaling,
                   const)
-    if (!missing(select)) 
-        pts <- pts[select, , drop = FALSE]
+    if (!missing(select))
+        pts <- .checkSelect(select, pts)
     if (display == "cn") {
         cnam <- rownames(pts)
         points(pts, ...)
@@ -16,7 +16,7 @@
                       const)
         bnam <- rownames(pts)
         pts <- pts[!(bnam %in% cnam), , drop = FALSE]
-        if (nrow(pts) == 0) 
+        if (nrow(pts) == 0)
             return(invisible())
         else display <- "bp"
     }
@@ -25,12 +25,12 @@
             arrow.mul <- ordiArrowMul(pts)
     	}
         pts <- pts * arrow.mul
-        arrows(0, 0, pts[, 1], pts[, 2], length = head.arrow, 
+        arrows(0, 0, pts[, 1], pts[, 2], length = head.arrow,
                ...)
         pts <- pts * 1.1
-        axis(3, at = c(-arrow.mul, 0, arrow.mul), labels = rep("", 
+        axis(3, at = c(-arrow.mul, 0, arrow.mul), labels = rep("",
                                                   3))
-        axis(4, at = c(-arrow.mul, 0, arrow.mul), labels = c(-1, 
+        axis(4, at = c(-arrow.mul, 0, arrow.mul), labels = c(-1,
                                                   0, 1))
         return(invisible())
     }
