@@ -1,14 +1,17 @@
-"procrustes" <-
+`procrustes` <-
     function (X, Y, scale = TRUE, symmetric = FALSE,  scores = "sites", ...) 
 {
     X <- scores(X, display = scores, ...)
     Y <- scores(Y, display = scores, ...)
+    if (nrow(X) != nrow(Y))
+        stop("Matrices have different number of rows: ",
+             nrow(X), " and ", nrow(Y))
     if (ncol(X) < ncol(Y)) {
         warning("X has fewer axes than Y: X adjusted to comform Y\n")
         addcols <- ncol(Y) - ncol(X)
         for (i in 1:addcols) X <- cbind(X, 0)
     }
-    ctrace <- function(MAT) sum(diag(crossprod(MAT)))
+    ctrace <- function(MAT) sum(MAT^2)
     c <- 1
     if (symmetric) {
         X <- scale(X, scale = FALSE)
@@ -38,5 +41,5 @@
                   symmetric = symmetric, call = match.call())
     reslt$svd <- sol
     class(reslt) <- "procrustes"
-    return(reslt)
+    reslt
 }
